@@ -5,7 +5,10 @@ from operator import mul
 import numpy
 from sklearn import model_selection
 
-from . import model
+from . import (
+    model,
+    preprocessing
+)
 
 
 logger = logging.getLogger(__name__)
@@ -64,8 +67,8 @@ class RandomizedSearchCV(model_selection.RandomizedSearchCV):
             conjurer.ml.Model
         """
         df = df.sample(len(df))  # shuffle
-        x = df[feature_columns].values
-        y = df[target_column].values
+        x = preprocessing.get_x(df, feature_columns)
+        y = preprocessing.get_y(df, target_column)
         self.cv = n_fold
         logger.warning("start learning with {} hyper parameters".format(self.n_iter))
         self.fit(x, y, **kwargs)
@@ -118,8 +121,8 @@ class GridSearchCV(model_selection.GridSearchCV):
             conjurer.ml.Model
         """
         df = df.sample(len(df))  # shuffle
-        x = df[feature_columns].values
-        y = df[target_column].values
+        x = preprocessing.get_x(df, feature_columns)
+        y = preprocessing.get_y(df, target_column)
         self.cv = n_fold
         logger.warning("start learning with {} parameters".format(_get_num_parameters(self.param_grid)))
         self.fit(x, y, **kwargs)
@@ -129,19 +132,25 @@ class GridSearchCV(model_selection.GridSearchCV):
 def _split_for_holdout(df_training, target_column, feature_columns, df_validation, ratio_training):
     if df_validation is not None:
         x = numpy.concatenate(
-            (df_training[feature_columns].values, df_validation[feature_columns].values),
+            (
+                preprocessing.get_x(df_training, feature_columns), 
+                preprocessing.get_x(df_validation, feature_columns)
+            ),
             axis=0
         )
         y = numpy.concatenate(
-            (df_training[target_column].values, df_validation[target_column].values),
+            (
+                preprocessing.get_y(df_training, target_column), 
+                preprocessing.get_y(df_validation, target_column)
+            ),
             axis=0
         )
         num_training = len(df_training)
         num_validation = len(df_validation)
     else:
         shuffled_df = df_training.sample(len(df_training))
-        x = shuffled_df[feature_columns].values
-        y = shuffled_df[target_column].values
+        x = preprocessing.get_x(shuffled_df, feature_columns)
+        y = preprocessing.get_y(shuffled_df, target_column)
         num_training = int(ratio_training * len(df_training))
         num_validation = len(df_training) - num_training
     return x, y, num_training, num_validation
